
#ifndef __PG_H__
#define __PG_H__

#include <libpq-fe.h>

#ifdef __cplusplus
extern "C" {
#endif

/* #########################################
 * PGparam API
 */

typedef struct pg_param PGparam;

PGparam *PQparamCreate(void);

/* Resets a PGparam for use again. */
void PQparamReset(PGparam *param);

char *PQparamErrorMessage(PGparam *param);

/* Frees a PGparam */
void PQparamClear(PGparam *param);

int PQparamExec(
  PGconn *conn,
  const char *command,
  PGparam *param,
  int resultFormat,
  PGresult **resultp);

int PQparamExecPrepared(
  PGconn *conn,
  const char *stmtName,
  PGparam *param,
  int resultFormat,
  PGresult **resultp);

int PQparamSend(
  PGconn *conn,
  const char *command,
  PGparam *param,
  int resultFormat);

int PQparamSendPrepared(
  PGconn *conn,
  const char *stmtName,
  PGparam *param,
  int resultFormat);

int PQparamPutChar(PGparam *param, unsigned char ch);

int PQparamPutInt2(PGparam *param, unsigned short i2);

int PQparamPutInt4(PGparam *param, unsigned int i4);

int PQparamPutInt8(PGparam *param, void *i8p);

int PQparamPutFloat(PGparam *param, float f);

int PQparamPutDouble(PGparam *param, double d);

/* If strl < 0, the length of str will be calculated using strlen(). */
int PQparamPutString(PGparam *param, const char *str, int strl);

int PQparamPut(
	PGparam *param,
	const void *data,
	int datal,
	int format);






/* #########################################
 * PGresult Extension API
 */

int PQgetchar(
	const PGresult *res,
	int tup_num,
	int field_num,
	unsigned char *charp);

int PQgetint2(
	const PGresult *res,
	int tup_num,
	int field_num,
	unsigned short *int2p);

int PQgetint4(
	const PGresult *res,
	int tup_num,
	int field_num,
	unsigned int *int4p);

int PQgetint8(
	const PGresult *res,
	int tup_num,
	int field_num,
	void *int8p);

#define PQgetfloat(res, tup_num, field_num, floatp) \
	PQgetint4(res, tup_num, field_num, (unsigned int *) ((void*) floatp))

#define PQgetdouble(res, tup_num, field_num, doublep) \
	PQgetint8(res, tup_num, field_num, (void *)(doublep))

#ifdef __cplusplus
}
#endif
#endif


